@@ -1,10 +1,10 @@
 /*
- *  $Id: icmp_redirect.c,v 1.1 2003/11/01 17:09:36 mike Exp $
+ *  $Id: icmp_redirect.c,v 1.3 2004/03/16 18:40:58 mike Exp $
  *
  *  libnet 1.1
  *  Build an ICMP redirect packet
  *
- *  Copyright (c) 1998 - 2003 Mike D. Schiffman <mike@infonexus.com>
+ *  Copyright (c) 1998 - 2004 Mike D. Schiffman <mike@infonexus.com>
  *  Copyright (c) 2003 Alberto Ornaghi <alor@antifork.org>
  *  All rights reserved.
  *
@@ -99,22 +99,34 @@ main(int argc, char **argv)
         exit(EXIT_FAILURE);
     }
     
+    t = libnet_build_ipv4(
+        LIBNET_IPV4_H + payload_s,                  /* length */
+        IPTOS_LOWDELAY | IPTOS_THROUGHPUT,          /* TOS */
+        0x42,                                       /* IP ID */
+        0,                                          /* IP Frag */
+        64,                                         /* TTL */
+        IPPROTO_ICMP,                               /* protocol */
+        0,                                          /* checksum */
+        dst_ip,                                     /* source IP */
+        src_ip,                                     /* destination IP */
+        payload,                                    /* payload */
+        payload_s,                                  /* payload size */
+        l,                                          /* libnet handle */
+        0);
+    if (t == -1)
+    {
+        fprintf(stderr, "Can't build error IP header: %s\n", 
+                libnet_geterror(l));
+        goto bad;
+    }
+
    t = libnet_build_icmpv4_redirect(
            ICMP_REDIRECT,                 /* type */
            ICMP_REDIRECT_HOST,            /* code */
            0,                             /* checksum */
            gw_ip,
-               LIBNET_IPV4_H + payload_s,              /* o length */
-               IPTOS_LOWDELAY | IPTOS_THROUGHPUT,      /* o IP tos */
-               0xff,                                   /* o IP ID */
-               0,                                      /* o frag */
-               64,                                     /* o TTL */
-               IPPROTO_UDP,                            /* o protocol */
-               0,                                      /* o checksum */
-               dst_ip,                                 /* o source IP */
-               src_ip,                                 /* o destination IP */
-               payload,                                /* payload */
-               payload_s,                              /* payload size */
+           NULL,
+           0,
            l,             /* libnet handle */
            0);                            /* libnet id */
     if (t == -1)
