@@ -1,10 +1,10 @@
 /*
- *  $Id: libnet_advanced.c,v 1.5 2003/10/30 23:26:32 mike Exp $
+ *  $Id: libnet_advanced.c,v 1.7 2004/02/16 23:13:38 mike Exp $
  *
  *  libnet
  *  libnet_advanced.c - Advanced routines
  *
- *  Copyright (c) 1998 - 2003 Mike D. Schiffman <mike@infonexus.com>
+ *  Copyright (c) 1998 - 2004 Mike D. Schiffman <mike@infonexus.com>
  *  All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -119,4 +119,18 @@ libnet_adv_write_link(libnet_t *l, u_int8_t *packet, u_int32_t packet_s)
     return (c);
 }
 
+void
+libnet_adv_free_packet(libnet_t *l, u_int8_t *packet)
+{
+    /*
+     *  Restore original pointer address so free won't complain about a
+     *  modified chunk pointer.
+     */
+    if (l->aligner > 0)
+    {
+        packet = packet - l->aligner;
+    }
+    free(packet);
+}
+
 /* EOF */
