@@ -1,10 +1,10 @@
 /*
- *  $Id: libnet_build_dhcp.c,v 1.8 2003/10/30 23:26:32 mike Exp $
+ *  $Id: libnet_build_dhcp.c,v 1.10 2004/03/01 20:26:12 mike Exp $
  *
  *  libnet
  *  libnet_build_dhcp.c - DHCP/BOOTP packet assembler
  *
- *  Copyright (c) 1998 - 2003 Mike D. Schiffman <mike@infonexus.com>
+ *  Copyright (c) 1998 - 2004 Mike D. Schiffman <mike@infonexus.com>
  *  All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -40,10 +40,11 @@
 #endif
 
 libnet_ptag_t
-libnet_build_dhcpv4(u_int8_t opcode, u_int8_t htype, u_int8_t hlen, u_int8_t hopcount,
-            u_int32_t xid, u_int16_t secs, u_int16_t flags, u_int32_t cip, u_int32_t yip,
-            u_int32_t sip, u_int32_t gip, u_int8_t *chaddr, u_int8_t *sname, u_int8_t *file,
-            u_int8_t *payload, u_int32_t payload_s, libnet_t *l, libnet_ptag_t ptag)
+libnet_build_dhcpv4(u_int8_t opcode, u_int8_t htype, u_int8_t hlen, 
+u_int8_t hopcount, u_int32_t xid, u_int16_t secs, u_int16_t flags,
+u_int32_t cip, u_int32_t yip, u_int32_t sip, u_int32_t gip, u_int8_t *chaddr,
+u_int8_t *sname, u_int8_t *file, u_int8_t *payload, u_int32_t payload_s,
+libnet_t *l, libnet_ptag_t ptag)
 {
     u_int32_t n, h;
     libnet_pblock_t *p; 
@@ -67,8 +68,8 @@ libnet_build_dhcpv4(u_int8_t opcode, u_int8_t htype, u_int8_t hlen, u_int8_t hop
         return (-1);
     }
 
-	memset(&dhcp_hdr, 0, sizeof(dhcp_hdr));
-	dhcp_hdr.dhcp_opcode    = opcode;
+    memset(&dhcp_hdr, 0, sizeof(dhcp_hdr));
+    dhcp_hdr.dhcp_opcode    = opcode;
     dhcp_hdr.dhcp_htype     = htype;
     dhcp_hdr.dhcp_hlen      = hlen;
     dhcp_hdr.dhcp_hopcount  = hopcount;
@@ -83,7 +84,7 @@ libnet_build_dhcpv4(u_int8_t opcode, u_int8_t htype, u_int8_t hlen, u_int8_t hop
     if (chaddr)
     { 
         memcpy(dhcp_hdr.dhcp_chaddr, chaddr, sizeof (dhcp_hdr.dhcp_chaddr));
-        dhcp_hdr.dhcp_chaddr[sizeof(dhcp_hdr.dhcp_chaddr)-1] = 0;
+        dhcp_hdr.dhcp_chaddr[sizeof(dhcp_hdr.dhcp_chaddr) - 1] = 0;
     }
     else
     {
@@ -93,7 +94,7 @@ libnet_build_dhcpv4(u_int8_t opcode, u_int8_t htype, u_int8_t hlen, u_int8_t hop
     if (sname)
     { 
         memcpy(dhcp_hdr.dhcp_sname, sname, sizeof (dhcp_hdr.dhcp_sname));
-        dhcp_hdr.dhcp_sname[sizeof(dhcp_hdr.dhcp_sname)-1] = 0;
+        dhcp_hdr.dhcp_sname[sizeof(dhcp_hdr.dhcp_sname) - 1] = 0;
     }
     else
     {
@@ -103,7 +104,7 @@ libnet_build_dhcpv4(u_int8_t opcode, u_int8_t htype, u_int8_t hlen, u_int8_t hop
     if (file)
     {
         memcpy(dhcp_hdr.dhcp_file, file, sizeof (dhcp_hdr.dhcp_file));
-        dhcp_hdr.dhcp_file[sizeof(dhcp_hdr.dhcp_file)-1] = 0;
+        dhcp_hdr.dhcp_file[sizeof(dhcp_hdr.dhcp_file) - 1] = 0;
     }
     else
     {
@@ -120,7 +121,7 @@ libnet_build_dhcpv4(u_int8_t opcode, u_int8_t htype, u_int8_t hlen, u_int8_t hop
     if ((payload && !payload_s) || (!payload && payload_s))
     {
          snprintf(l->err_buf, LIBNET_ERRBUF_SIZE,
-			     "%s(): payload inconsistency\n", __func__);
+                 "%s(): payload inconsistency\n", __func__);
         goto bad;
     }
  
@@ -140,12 +141,12 @@ bad:
     return (-1);
 }
 
-
 libnet_ptag_t
-libnet_build_bootpv4(u_int8_t opcode, u_int8_t htype, u_int8_t hlen, u_int8_t hopcount,
-            u_int32_t xid, u_int16_t secs, u_int16_t flags, u_int32_t cip, u_int32_t yip,
-            u_int32_t sip, u_int32_t gip, u_int8_t *chaddr, u_int8_t *sname, u_int8_t *file,
-            u_int8_t *payload, u_int32_t payload_s, libnet_t *l, libnet_ptag_t ptag)
+libnet_build_bootpv4(u_int8_t opcode, u_int8_t htype, u_int8_t hlen,
+u_int8_t hopcount, u_int32_t xid, u_int16_t secs, u_int16_t flags,
+u_int32_t cip, u_int32_t yip, u_int32_t sip, u_int32_t gip, u_int8_t *chaddr,
+u_int8_t *sname, u_int8_t *file, u_int8_t *payload, u_int32_t payload_s,
+libnet_t *l, libnet_ptag_t ptag)
 {
     return (libnet_build_dhcpv4(opcode, htype, hlen, hopcount, xid, secs,
         flags, cip, yip, sip, gip, chaddr, sname, file, payload, payload_s, 
