@@ -2,7 +2,7 @@
  *  libnet
  *  libnet_build_fddi.c - Fiber Distributed Data Interface packet assembler
  *
- *  Copyright (c) 1998 - 2003 Mike D. Schiffman <mike@infonexus.com>
+ *  Copyright (c) 1998 - 2004 Mike D. Schiffman <mike@infonexus.com>
  *                            Jason Damron      <jsdamron@hushmail.com>
  *  All rights reserved.
  *
@@ -40,9 +40,8 @@
 
 libnet_ptag_t
 libnet_build_fddi(u_int8_t fc, u_int8_t *dst, u_int8_t *src, u_int8_t dsap,
-                  u_int8_t ssap, u_int8_t cf, u_int8_t *org, u_int16_t type,
-                  u_int8_t *payload, u_int32_t payload_s, libnet_t *l, 
-                  libnet_ptag_t ptag)
+u_int8_t ssap, u_int8_t cf, u_int8_t *org, u_int16_t type, u_int8_t *payload,
+u_int32_t payload_s, libnet_t *l, libnet_ptag_t ptag)
 {
     u_int32_t n, h;
     u_int16_t protocol_type;
