@@ -108,21 +108,38 @@
  *      
  */
 
-static inline void libnet_print_gre_flags_ver(u_int16_t fv)
+static inline void
+__libnet_print_gre_flags_ver(u_int16_t fv)
 {
-    printf("version = %d (%d) -> ", 
-            fv & GRE_VERSION_MASK, libnet_gre_length(fv));
-    if (fv & GRE_CSUM) printf("CSUM ");
-    if (fv & GRE_ROUTING) printf("ROUTING ");
-    if (fv & GRE_KEY) printf("KEY ");
-    if (fv & GRE_SEQ) printf("SEQ ");
-    if (fv & GRE_ACK) printf("ACK ");
+    printf("version = %d (%d) -> ",
+        fv & GRE_VERSION_MASK, libnet_getgre_length(fv));
+    if (fv & GRE_CSUM)
+    {
+        printf("CSUM ");
+    }
+    if (fv & GRE_ROUTING)
+    {
+        printf("ROUTING ");
+    }
+    if (fv & GRE_KEY)
+    {
+        printf("KEY ");
+    }
+    if (fv & GRE_SEQ)
+    {
+        printf("SEQ ");
+    }
+    if (fv & GRE_ACK)
+    {
+        printf("ACK ");
+    }
     printf("\n");
 }
 
 
 /* FIXME: what is the portability of the "((struct libnet_gre_hdr*)0)->" ? */
-inline u_int32_t libnet_gre_length(u_int16_t fv)
+inline u_int32_t
+libnet_getgre_length(u_int16_t fv)
 {
 
     u_int32_t n = LIBNET_GRE_H;
@@ -135,30 +152,29 @@ inline u_int32_t libnet_gre_length(u_int16_t fv)
     if ((!(fv & GRE_VERSION_MASK) && (fv & (GRE_CSUM|GRE_ROUTING))) || /* v0 */
 	(fv & GRE_VERSION_MASK) )                                      /* v1 */
     {
-	n+=sizeof( ((struct libnet_gre_hdr*)0)->gre_checksum) + 
-	    sizeof( ((struct libnet_gre_hdr*)0)->gre_offset);
+	n += sizeof( ((struct libnet_gre_hdr *)0)->gre_sum) + 
+	    sizeof( ((struct libnet_gre_hdr *)0)->gre_offset);
     }
 
     if ((!(fv & GRE_VERSION_MASK) && (fv & GRE_KEY)) ||                /* v0 */
 	( (fv & GRE_VERSION_MASK) && (fv & GRE_SEQ)) )                 /* v1 */
     {
-	n+=sizeof( ((struct libnet_gre_hdr*)0)->gre_key);
+	n += sizeof( ((struct libnet_gre_hdr *)0)->gre_key);
     }
 
     if ((!(fv & GRE_VERSION_MASK) && (fv & GRE_SEQ)) ||                /* v0 */
 	( (fv & GRE_VERSION_MASK) && (fv & GRE_ACK)) )                 /* v1 */
     {
-	n+=sizeof( ((struct libnet_gre_hdr*)0)->gre_seq );
+	n += sizeof( ((struct libnet_gre_hdr *)0)->gre_seq );
     }
 
-    return n;
+    return (n);
 }
 
-
 libnet_ptag_t
-libnet_build_gre(u_int16_t fv, u_int16_t type, u_int16_t checksum, 
-		 u_int16_t offset, u_int32_t key, u_int32_t seq, u_int16_t len,
-		 u_int8_t *payload, u_int32_t payload_s, libnet_t *l, libnet_ptag_t ptag)
+libnet_build_gre(u_int16_t fv, u_int16_t type, u_int16_t sum, 
+u_int16_t offset, u_int32_t key, u_int32_t seq, u_int16_t len,
+u_int8_t *payload, u_int32_t payload_s, libnet_t *l, libnet_ptag_t ptag)
 {
     u_int32_t n;
     libnet_pblock_t *p;
@@ -169,7 +185,7 @@ libnet_build_gre(u_int16_t fv, u_int16_t type, u_int16_t checksum,
         return (-1); 
     }
 
-    n = libnet_gre_length(fv) + payload_s;
+    n = libnet_getgre_length(fv) + payload_s;
 
     /*
      *  Find the existing protocol block if a ptag is specified, or create
@@ -193,15 +209,17 @@ libnet_build_gre(u_int16_t fv, u_int16_t type, u_int16_t checksum,
     if ((!(fv & GRE_VERSION_MASK) && (fv & (GRE_CSUM|GRE_ROUTING))) || /* v0 */
 	(fv & GRE_VERSION_MASK))                                       /* v1 */
     {
-	checksum = htons(checksum);
-	n = libnet_pblock_append(l, p, (u_int8_t*)&checksum, sizeof(gre_hdr.gre_checksum));
+        sum = htons(sum);
+        n = libnet_pblock_append(l, p, (u_int8_t*)&sum,
+                sizeof(gre_hdr.gre_sum));
 	if (n == -1)
 	{
 	    /* err msg set in libnet_pblock_append() */
 	    goto bad;
 	}
 	offset = htons(offset);
-	n = libnet_pblock_append(l, p, (u_int8_t*)&offset, sizeof(gre_hdr.gre_offset));
+	n = libnet_pblock_append(l, p, (u_int8_t*)&offset, 
+                sizeof(gre_hdr.gre_offset));
 	if (n == -1)
 	{
 	    /* err msg set in libnet_pblock_append() */
@@ -213,7 +231,8 @@ libnet_build_gre(u_int16_t fv, u_int16_t type, u_int16_t checksum,
 	( (fv & GRE_VERSION_MASK) && (fv & GRE_SEQ)) )                 /* v1 */
     {
 	key = htonl(key);
-	n = libnet_pblock_append(l, p, (u_int8_t*)&key, sizeof(gre_hdr.gre_key));
+	n = libnet_pblock_append(l, p, (u_int8_t*)&key,
+                sizeof(gre_hdr.gre_key));
 	if (n == -1)
 	{
 	    /* err msg set in libnet_pblock_append() */
@@ -225,7 +244,8 @@ libnet_build_gre(u_int16_t fv, u_int16_t type, u_int16_t checksum,
 	( (fv & GRE_VERSION_MASK) && (fv & GRE_ACK)) )                 /* v1 */
     {
 	seq = htonl(seq);
-	n = libnet_pblock_append(l, p, (u_int8_t*)&seq, sizeof(gre_hdr.gre_seq));
+	n = libnet_pblock_append(l, p, (u_int8_t*)&seq, 
+                sizeof(gre_hdr.gre_seq));
 	if (n == -1)
 	{
 	    /* err msg set in libnet_pblock_append() */
@@ -249,7 +269,7 @@ libnet_build_gre(u_int16_t fv, u_int16_t type, u_int16_t checksum,
         }
     }
 
-    if ( (fv & GRE_CSUM) && (!checksum) )
+    if ( (fv & GRE_CSUM) && (!sum) )
     {
 	libnet_pblock_setflags(p, LIBNET_PBLOCK_DO_CHECKSUM);
     }
@@ -261,6 +281,15 @@ bad:
     return (-1);
 }
 
+libnet_ptag_t
+libnet_build_egre(u_int16_t fv, u_int16_t type, u_int16_t sum, 
+u_int16_t offset, u_int32_t key, u_int32_t seq, u_int16_t len,
+u_int8_t *payload, u_int32_t payload_s, libnet_t *l, libnet_ptag_t ptag)
+{
+    return (libnet_build_gre(fv, type, sum, offset, key, seq, len, 
+           payload, payload_s, l, ptag));
+}
+
 /*
  *    Routing (variable)
  *
@@ -280,8 +309,9 @@ bad:
  *
  */
 libnet_ptag_t
-libnet_build_gre_sre(u_int16_t af, u_int8_t offset, u_int8_t length, u_int8_t *routing,
-		     u_int8_t *payload, u_int32_t payload_s, libnet_t *l, libnet_ptag_t ptag)
+libnet_build_gre_sre(u_int16_t af, u_int8_t offset, u_int8_t length, 
+u_int8_t *routing, u_int8_t *payload, u_int32_t payload_s, libnet_t *l,
+libnet_ptag_t ptag)
 {
     u_int32_t n;
     libnet_pblock_t *p;
@@ -303,7 +333,7 @@ libnet_build_gre_sre(u_int16_t af, u_int8_t offset, u_int8_t length, u_int8_t *r
     {
         return (-1);
     }
-    sre_hdr.af = af;
+    sre_hdr.af = htons(af);
     sre_hdr.sre_offset = offset;
     sre_hdr.sre_length = length;
     n = libnet_pblock_append(l, p, (u_int8_t *)&sre_hdr, LIBNET_GRE_SRE_H);
@@ -345,7 +375,8 @@ libnet_build_gre_sre(u_int16_t af, u_int8_t offset, u_int8_t length, u_int8_t *r
         }
     }
 
-    return (ptag ? ptag : libnet_pblock_update(l, p, 0, LIBNET_PBLOCK_GRE_SRE_H));
+    return (ptag ? ptag : libnet_pblock_update(l, p, 0, 
+           LIBNET_PBLOCK_GRE_SRE_H));
 
 bad:
     libnet_pblock_delete(l, p);
@@ -383,7 +414,8 @@ libnet_build_gre_last_sre(libnet_t *l, libnet_ptag_t ptag)
         goto bad; 
     }
 
-    return (ptag ? ptag : libnet_pblock_update(l, p, 0, LIBNET_PBLOCK_GRE_SRE_H));
+    return (ptag ? ptag : libnet_pblock_update(l, p, 0, 
+           LIBNET_PBLOCK_GRE_SRE_H));
 
 bad:
     libnet_pblock_delete(l, p);
