@@ -1,5 +1,5 @@
 /*
- *  $Id: libnet_build_icmp.c,v 1.15 2004/03/25 18:50:48 mike Exp $
+ *  $Id: libnet_build_icmp.c,v 1.16 2004/03/29 17:24:34 mike Exp $
  *
  *  libnet
  *  libnet_build_icmp.c - ICMP packet assemblers
@@ -40,10 +40,10 @@
 #endif
 
 /* some common cruft for completing ICMP error packets */
-#define LIBNET_BUILD_ICMP_ERR_FINISH(type)                                   \
+#define LIBNET_BUILD_ICMP_ERR_FINISH(len)                                    \
 do                                                                           \
 {                                                                            \
-    n = libnet_pblock_append(l, p, (u_int8_t *)&icmp_hdr, type);             \
+    n = libnet_pblock_append(l, p, (u_int8_t *)&icmp_hdr, len);              \
     if (n == -1)                                                             \
     {                                                                        \
         goto bad;                                                            \
@@ -425,7 +425,7 @@ libnet_ptag_t ptag)
     icmp_hdr.icmp_sum       = (sum ? htons(sum) : 0);  /* checksum */
     icmp_hdr.hun.gateway    = gateway;
 
-    LIBNET_BUILD_ICMP_ERR_FINISH(LIBNET_PBLOCK_ICMPV4_REDIRECT_H);
+    LIBNET_BUILD_ICMP_ERR_FINISH(LIBNET_ICMPV4_REDIRECT_H);
 
     return (ptag ? ptag : libnet_pblock_update(l, p, h,
             LIBNET_PBLOCK_ICMPV4_REDIRECT_H));
