@@ -1,10 +1,10 @@
 /*
- *  $Id: libnet_build_igmp.c,v 1.9 2003/11/25 20:40:52 mike Exp $
+ *  $Id: libnet_build_igmp.c,v 1.11 2004/01/21 19:01:29 mike Exp $
  *
  *  libnet
  *  libnet_build_igmp.c - IGMP packet assembler
  *
- *  Copyright (c) 1998 - 2003 Mike D. Schiffman <mike@infonexus.com>
+ *  Copyright (c) 1998 - 2004 Mike D. Schiffman <mike@infonexus.com>
  *  All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -41,8 +41,7 @@
 
 libnet_ptag_t
 libnet_build_igmp(u_int8_t type, u_int8_t code, u_int16_t sum, u_int32_t ip,
-            u_int8_t *payload, u_int32_t payload_s, libnet_t *l,
-            libnet_ptag_t ptag)
+u_int8_t *payload, u_int32_t payload_s, libnet_t *l, libnet_ptag_t ptag)
 {
     u_int32_t n, h;
     libnet_pblock_t *p;
@@ -53,7 +52,7 @@ libnet_build_igmp(u_int8_t type, u_int8_t code, u_int16_t sum, u_int32_t ip,
         return (-1);
     } 
 
-    n = LIBNET_IGMP_H + payload_s;      /* IGMP has no payload though! */
+    n = LIBNET_IGMP_H + payload_s;
     h = LIBNET_IGMP_H;
 
     /*
@@ -69,8 +68,8 @@ libnet_build_igmp(u_int8_t type, u_int8_t code, u_int16_t sum, u_int32_t ip,
     memset(&igmp_hdr, 0, sizeof(igmp_hdr));
     igmp_hdr.igmp_type         = type;    /* packet type */
     igmp_hdr.igmp_code         = code;    /* packet code */
-    igmp_hdr.igmp_sum          = sum;     /* packet checksum */
-    igmp_hdr.igmp_group.s_addr = ip;      /* group address or 0 */       
+    igmp_hdr.igmp_sum          = (sum ? htons(sum) : 0);  /* packet checksum */
+    igmp_hdr.igmp_group.s_addr = htonl(ip);
 
     n = libnet_pblock_append(l, p, (u_int8_t *)&igmp_hdr, LIBNET_IGMP_H);
     if (n == -1)
