@@ -1,10 +1,10 @@
 /*
- *  $Id: libnet_build_ip.c,v 1.12 2003/11/03 03:01:22 mike Exp $
+ *  $Id: libnet_build_ip.c,v 1.18 2004/03/16 18:40:59 mike Exp $
  *
  *  libnet
  *  libnet_build_ip.c - IP packet assembler
  *
- *  Copyright (c) 1998 - 2003 Mike D. Schiffman <mike@infonexus.com>
+ *  Copyright (c) 1998 - 2004 Mike D. Schiffman <mike@infonexus.com>
  *  All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -42,9 +42,8 @@
 
 libnet_ptag_t
 libnet_build_ipv4(u_int16_t len, u_int8_t tos, u_int16_t id, u_int16_t frag,
-            u_int8_t ttl, u_int8_t prot, u_int16_t sum, u_int32_t src,
-            u_int32_t dst, u_int8_t *payload, u_int32_t payload_s,
-            libnet_t *l, libnet_ptag_t ptag)
+u_int8_t ttl, u_int8_t prot, u_int16_t sum, u_int32_t src, u_int32_t dst,
+u_int8_t *payload, u_int32_t payload_s, libnet_t *l, libnet_ptag_t ptag)
 {
     int offset;
     u_int32_t h, n, i, j;
@@ -64,7 +63,7 @@ libnet_build_ipv4(u_int16_t len, u_int8_t tos, u_int16_t id, u_int16_t frag,
     if (h + payload_s > IP_MAXPACKET)
     {
          snprintf(l->err_buf, LIBNET_ERRBUF_SIZE,
-			     "%s(): IP packet too large\n", __func__);
+                "%s(): IP packet too large\n", __func__);
         return (-1);
     }
 
@@ -105,11 +104,11 @@ libnet_build_ipv4(u_int16_t len, u_int8_t tos, u_int16_t id, u_int16_t frag,
     ip_hdr.ip_off        = htons(frag);               /* fragmentation flags */
     ip_hdr.ip_ttl        = ttl;                       /* time to live */
     ip_hdr.ip_p          = prot;                      /* transport protocol */
-    ip_hdr.ip_sum        = sum;                       /* checksum */
+    ip_hdr.ip_sum        = (sum ? htons(sum) : 0);    /* checksum */
     ip_hdr.ip_src.s_addr = src;                       /* source ip */
     ip_hdr.ip_dst.s_addr = dst;                       /* destination ip */
     
-	n = libnet_pblock_append(l, p, (u_int8_t *)&ip_hdr, LIBNET_IPV4_H);
+    n = libnet_pblock_append(l, p, (u_int8_t *)&ip_hdr, LIBNET_IPV4_H);
     if (n == -1)
     {
         goto bad;
@@ -151,7 +150,7 @@ libnet_build_ipv4(u_int16_t len, u_int8_t tos, u_int16_t id, u_int16_t frag,
     if ((payload && !payload_s) || (!payload && payload_s))
     {
          snprintf(l->err_buf, LIBNET_ERRBUF_SIZE,
-			     "%s(): payload inconsistency\n", __func__);
+                 "%s(): payload inconsistency\n", __func__);
         goto bad;
     }
 
@@ -234,6 +233,13 @@ libnet_build_ipv4(u_int16_t len, u_int8_t tos, u_int16_t id, u_int16_t frag,
          */
         libnet_pblock_setflags(p, LIBNET_PBLOCK_DO_CHECKSUM);
     }
+
+    /*
+     * FREDRAYNAL: as we insert a new IP header, all checksums for headers
+     * placed after this one will refer to here.
+     */
+    libnet_pblock_record_ip_offset(l, l->total_size);
+
     return (ptag);
 bad:
     libnet_pblock_delete(l, p);
@@ -273,8 +279,8 @@ libnet_autobuild_ipv4(u_int16_t len, u_int8_t prot, u_int32_t dst, libnet_t *l)
         return (-1);
     }
 	
-	memset(&ip_hdr, 0, sizeof(ip_hdr));
-	ip_hdr.ip_v          = 4;                         /* version 4 */
+    memset(&ip_hdr, 0, sizeof(ip_hdr));
+    ip_hdr.ip_v          = 4;                         /* version 4 */
     ip_hdr.ip_hl         = 5;                         /* 20 byte header */
 
     /* check to see if there are IP options to include */
@@ -311,7 +317,15 @@ libnet_autobuild_ipv4(u_int16_t len, u_int8_t prot, u_int32_t dst, libnet_t *l)
     }
 
     libnet_pblock_setflags(p, LIBNET_PBLOCK_DO_CHECKSUM);
-    return (libnet_pblock_update(l, p, LIBNET_IPV4_H, LIBNET_PBLOCK_IPV4_H));
+    ptag = libnet_pblock_update(l, p, LIBNET_IPV4_H, LIBNET_PBLOCK_IPV4_H);
+
+    /*
+     * FREDRAYNAL: as we insert a new IP header, all checksums for headers
+     * placed after this one will refer to here.
+     */
+    libnet_pblock_record_ip_offset(l, l->total_size);
+    return (ptag);
+
 bad:
     libnet_pblock_delete(l, p);
     return (-1);
@@ -319,7 +333,7 @@ bad:
 
 libnet_ptag_t
 libnet_build_ipv4_options(u_int8_t *options, u_int32_t options_s, libnet_t *l, 
-            libnet_ptag_t ptag)
+libnet_ptag_t ptag)
 {
     int offset, underflow;
     u_int32_t i, j, n, adj_size;
@@ -441,9 +455,8 @@ bad:
 
 libnet_ptag_t
 libnet_build_ipv6(u_int8_t tc, u_int32_t fl, u_int16_t len, u_int8_t nh,
-             u_int8_t hl, struct libnet_in6_addr src, 
-             struct libnet_in6_addr dst,  u_int8_t *payload, 
-             u_int32_t payload_s, libnet_t *l, libnet_ptag_t ptag)
+u_int8_t hl, struct libnet_in6_addr src, struct libnet_in6_addr dst, 
+u_int8_t *payload, u_int32_t payload_s, libnet_t *l, libnet_ptag_t ptag)
 {   
     u_int32_t n;
     libnet_pblock_t *p;
@@ -459,7 +472,7 @@ libnet_build_ipv6(u_int8_t tc, u_int32_t fl, u_int16_t len, u_int8_t nh,
     if (LIBNET_IPV6_H + payload_s > IP_MAXPACKET)
     {  
          snprintf(l->err_buf, LIBNET_ERRBUF_SIZE,
-			     "%s(): IP packet too large\n", __func__);
+                 "%s(): IP packet too large\n", __func__);
         return (-1);
     }  
        
@@ -473,12 +486,11 @@ libnet_build_ipv6(u_int8_t tc, u_int32_t fl, u_int16_t len, u_int8_t nh,
         return (-1);
     }  
     
-	memset(&ip_hdr, 0, sizeof(ip_hdr));
-	ip_hdr.ip_flags[0] =  0x06 << 4;
-    ip_hdr.ip_flags[1] = 0;
-    ip_hdr.ip_flags[2] = 0;
-    ip_hdr.ip_flags[3] = 0;
-    /* XXX: TODO: traffic class, flow label */
+    memset(&ip_hdr, 0, sizeof(ip_hdr));
+    ip_hdr.ip_flags[0] = 0x06 << 4;
+    ip_hdr.ip_flags[1] = ((tc & 0x0F) << 4) | ((fl & 0xF0000) >> 16);
+    ip_hdr.ip_flags[2] = fl & 0x0FF00 >> 8;
+    ip_hdr.ip_flags[3] = fl & 0x000FF;
     ip_hdr.ip_len      = htons(len);
     ip_hdr.ip_nh       = nh;
     ip_hdr.ip_hl       = hl;
@@ -494,7 +506,7 @@ libnet_build_ipv6(u_int8_t tc, u_int32_t fl, u_int16_t len, u_int8_t nh,
     if ((payload && !payload_s) || (!payload && payload_s))
     {
          snprintf(l->err_buf, LIBNET_ERRBUF_SIZE,
-			     "%s(): payload inconsistency\n", __func__);
+                 "%s(): payload inconsistency\n", __func__);
         goto bad;
     }
  
@@ -515,6 +527,345 @@ bad:
     return (-1);
 }
 
+libnet_ptag_t
+libnet_build_ipv6_frag(u_int8_t nh, u_int8_t reserved, u_int16_t frag,
+u_int32_t id, u_int8_t *payload, u_int32_t payload_s, libnet_t *l,
+libnet_ptag_t ptag)
+{
+    u_int32_t n;
+    u_int16_t h;
+    libnet_pblock_t *p;
+    struct libnet_ipv6_frag_hdr ipv6_frag_hdr;
+
+    if (l == NULL)
+    { 
+        return (-1);
+    }
+
+    n = LIBNET_IPV6_FRAG_H + payload_s;
+    h = 0; 
+
+    if (LIBNET_IPV6_FRAG_H + payload_s > IP_MAXPACKET)
+    {
+         snprintf(l->err_buf, LIBNET_ERRBUF_SIZE,
+                 "%s(): IP packet too large\n", __func__);
+        return (-1);
+    }
+
+    /*
+     *  Find the existing protocol block if a ptag is specified, or create
+     *  a new one.
+     */
+    p = libnet_pblock_probe(l, ptag, n, LIBNET_PBLOCK_IPV6_FRAG_H);
+    if (p == NULL)
+    {
+        return (-1);
+    }
+
+    memset(&ipv6_frag_hdr, 0 , sizeof(ipv6_frag_hdr));
+    ipv6_frag_hdr.ip_nh       = nh;
+    ipv6_frag_hdr.ip_reserved = reserved;
+    ipv6_frag_hdr.ip_frag     = frag;
+    ipv6_frag_hdr.ip_id       = id;
+
+    /*
+     *  Appened the protocol unit to the list.
+     */
+    n = libnet_pblock_append(l, p, (u_int8_t *)&ipv6_frag_hdr,
+        LIBNET_IPV6_FRAG_H);
+    if (n == -1)
+    {
+        goto bad;
+    }
+
+    /*
+     *  Sanity check the payload arguments.
+     */
+    if ((payload && !payload_s) || (!payload && payload_s))
+    {
+        sprintf(l->err_buf, "%s(): payload inconsistency\n", __func__);
+        goto bad;
+    }
+
+    /*
+     *  Append the payload to the list if it exists.
+     */
+    if (payload && payload_s)
+    {
+        n = libnet_pblock_append(l, p, payload, payload_s);
+        if (n == -1)
+        {
+            goto bad;
+        }
+    }
+
+    /*
+     *  Update the protocol block's meta information and return the protocol
+     *  tag id of this pblock.  This tag will be used to locate the pblock
+     *  in order to modify the protocol header in subsequent calls.
+     */
+    return (ptag ? ptag : libnet_pblock_update(l, p, h, 
+            LIBNET_PBLOCK_IPV6_FRAG_H));
+bad:
+    libnet_pblock_delete(l, p);
+    return (-1);
+}
+
+libnet_ptag_t
+libnet_build_ipv6_routing(u_int8_t nh, u_int8_t len, u_int8_t rtype, 
+u_int8_t segments, u_int8_t *payload, u_int32_t payload_s, libnet_t *l,
+libnet_ptag_t ptag)
+{
+    u_int32_t n;
+    u_int16_t h;
+    libnet_pblock_t *p;
+    struct libnet_ipv6_routing_hdr ipv6_routing_hdr;
+
+    if (l == NULL)
+    { 
+        return (-1);
+    }
+
+    /* Important: IPv6 routing header routes are specified using the payload
+     * interface!
+     */
+    n = LIBNET_IPV6_ROUTING_H + payload_s;
+    h = 0;
+
+    if (LIBNET_IPV6_ROUTING_H + payload_s > IP_MAXPACKET)
+    {
+         snprintf(l->err_buf, LIBNET_ERRBUF_SIZE,
+                 "%s(): IP packet too large\n", __func__);
+        return (-1);
+    }
+
+    /*
+     *  Find the existing protocol block if a ptag is specified, or create
+     *  a new one.
+     */
+    p = libnet_pblock_probe(l, ptag, n, LIBNET_PBLOCK_IPV6_ROUTING_H);
+    if (p == NULL)
+    {
+        return (-1);
+    }
+
+    memset(&ipv6_routing_hdr, 0 , sizeof(ipv6_routing_hdr));
+    ipv6_routing_hdr.ip_nh       = nh;
+    ipv6_routing_hdr.ip_len      = len;
+    ipv6_routing_hdr.ip_rtype    = rtype;
+    ipv6_routing_hdr.ip_segments = segments;
+
+    /*
+     *  Appened the protocol unit to the list.
+     */
+    n = libnet_pblock_append(l, p, (u_int8_t *)&ipv6_routing_hdr,
+        LIBNET_IPV6_ROUTING_H);
+    if (n == -1)
+    {
+        goto bad;
+    }
+
+    /*
+     *  Sanity check the payload arguments.
+     */
+    if ((payload && !payload_s) || (!payload && payload_s))
+    {
+        sprintf(l->err_buf, "%s(): payload inconsistency\n", __func__);
+        goto bad;
+    }
+
+    /*
+     *  Append the payload to the list if it exists.
+     */
+    if (payload && payload_s)
+    {
+        n = libnet_pblock_append(l, p, payload, payload_s);
+        if (n == -1)
+        {
+            goto bad;
+        }
+    }
+
+    /*
+     *  Update the protocol block's meta information and return the protocol
+     *  tag id of this pblock.  This tag will be used to locate the pblock
+     *  in order to modify the protocol header in subsequent calls.
+     */
+    return (ptag ? ptag : libnet_pblock_update(l, p, h, 
+            LIBNET_PBLOCK_IPV6_ROUTING_H));
+bad:
+    libnet_pblock_delete(l, p);
+    return (-1);
+}
+
+libnet_ptag_t
+libnet_build_ipv6_destopts(u_int8_t nh, u_int8_t len, u_int8_t *payload,
+u_int32_t payload_s, libnet_t *l, libnet_ptag_t ptag)
+{
+    u_int32_t n;
+    u_int16_t h;
+    libnet_pblock_t *p;
+    struct libnet_ipv6_destopts_hdr ipv6_destopts_hdr;
+
+    if (l == NULL)
+    { 
+        return (-1);
+    }
+
+    /* Important: IPv6 dest opts information is specified using the payload
+     * interface!
+     */
+    n = LIBNET_IPV6_DESTOPTS_H + payload_s;
+    h = 0;
+
+    if (LIBNET_IPV6_DESTOPTS_H + payload_s > IP_MAXPACKET)
+    {
+         snprintf(l->err_buf, LIBNET_ERRBUF_SIZE,
+                 "%s(): IP packet too large\n", __func__);
+        return (-1);
+    }
+
+    /*
+     *  Find the existing protocol block if a ptag is specified, or create
+     *  a new one.
+     */
+    p = libnet_pblock_probe(l, ptag, n, LIBNET_PBLOCK_IPV6_DESTOPTS_H);
+    if (p == NULL)
+    {
+        return (-1);
+    }
+
+    memset(&ipv6_destopts_hdr, 0 , sizeof(ipv6_destopts_hdr));
+    ipv6_destopts_hdr.ip_nh  = nh;
+    ipv6_destopts_hdr.ip_len = len;
+
+    /*
+     *  Appened the protocol unit to the list.
+     */
+    n = libnet_pblock_append(l, p, (u_int8_t *)&ipv6_destopts_hdr,
+        LIBNET_IPV6_DESTOPTS_H);
+    if (n == -1)
+    {
+        goto bad;
+    }
+
+    /*
+     *  Sanity check the payload arguments.
+     */
+    if ((payload && !payload_s) || (!payload && payload_s))
+    {
+        sprintf(l->err_buf, "%s(): payload inconsistency\n", __func__);
+        goto bad;
+    }
+
+    /*
+     *  Append the payload to the list if it exists.
+     */
+    if (payload && payload_s)
+    {
+        n = libnet_pblock_append(l, p, payload, payload_s);
+        if (n == -1)
+        {
+            goto bad;
+        }
+    }
+
+    /*
+     *  Update the protocol block's meta information and return the protocol
+     *  tag id of this pblock.  This tag will be used to locate the pblock
+     *  in order to modify the protocol header in subsequent calls.
+     */
+    return (ptag ? ptag : libnet_pblock_update(l, p, h, 
+            LIBNET_PBLOCK_IPV6_DESTOPTS_H));
+bad:
+    libnet_pblock_delete(l, p);
+    return (-1);
+}
+
+libnet_ptag_t
+libnet_build_ipv6_hbhopts(u_int8_t nh, u_int8_t len, u_int8_t *payload,
+u_int32_t payload_s, libnet_t *l, libnet_ptag_t ptag)
+{
+    u_int32_t n;
+    u_int16_t h;
+    libnet_pblock_t *p;
+    struct libnet_ipv6_hbhopts_hdr ipv6_hbhopts_hdr;
+
+    if (l == NULL)
+    { 
+        return (-1);
+    }
+
+    /* Important: IPv6 hop by hop opts information is specified using the
+     * payload interface!
+     */
+    n = LIBNET_IPV6_HBHOPTS_H + payload_s;
+    h = 0;
+
+    if (LIBNET_IPV6_HBHOPTS_H + payload_s > IP_MAXPACKET)
+    {
+         snprintf(l->err_buf, LIBNET_ERRBUF_SIZE,
+                 "%s(): IP packet too large\n", __func__);
+        return (-1);
+    }
+
+    /*
+     *  Find the existing protocol block if a ptag is specified, or create
+     *  a new one.
+     */
+    p = libnet_pblock_probe(l, ptag, n, LIBNET_PBLOCK_IPV6_HBHOPTS_H);
+    if (p == NULL)
+    {
+        return (-1);
+    }
+
+    memset(&ipv6_hbhopts_hdr, 0 , sizeof(ipv6_hbhopts_hdr));
+    ipv6_hbhopts_hdr.ip_nh  = nh;
+    ipv6_hbhopts_hdr.ip_len = len;
+
+    /*
+     *  Appened the protocol unit to the list.
+     */
+    n = libnet_pblock_append(l, p, (u_int8_t *)&ipv6_hbhopts_hdr,
+        LIBNET_IPV6_HBHOPTS_H);
+    if (n == -1)
+    {
+        goto bad;
+    }
+
+    /*
+     *  Sanity check the payload arguments.
+     */
+    if ((payload && !payload_s) || (!payload && payload_s))
+    {
+        sprintf(l->err_buf, "%s(): payload inconsistency\n", __func__);
+        goto bad;
+    }
+
+    /*
+     *  Append the payload to the list if it exists.
+     */
+    if (payload && payload_s)
+    {
+        n = libnet_pblock_append(l, p, payload, payload_s);
+        if (n == -1)
+        {
+            goto bad;
+        }
+    }
+
+    /*
+     *  Update the protocol block's meta information and return the protocol
+     *  tag id of this pblock.  This tag will be used to locate the pblock
+     *  in order to modify the protocol header in subsequent calls.
+     */
+    return (ptag ? ptag : libnet_pblock_update(l, p, h, 
+            LIBNET_PBLOCK_IPV6_HBHOPTS_H));
+bad:
+    libnet_pblock_delete(l, p);
+    return (-1);
+}
+
 libnet_ptag_t
 libnet_autobuild_ipv6(u_int16_t len, u_int8_t nh, struct libnet_in6_addr dst,
             libnet_t *l)
@@ -522,19 +873,8 @@ libnet_autobuild_ipv6(u_int16_t len, u_int8_t nh, struct libnet_in6_addr dst,
 
     /* NYI */
      snprintf(l->err_buf, LIBNET_ERRBUF_SIZE,
-		     "%s(): not yet implemented\n", __func__);
+             "%s(): not yet implemented\n", __func__);
     return (-1);
-
-#if 0
-    struct libnet_in6_addr src = libnet_get_ipaddr6(l);
-
-    if (strncmp((int8_t*)&src, (int8_t*)&in6addr_error, sizeof(in6addr_error)) == 0)
-    {
-        return (-1);
-    }
-
-    return (libnet_build_ipv6(0, 0, len, nh, 64, src, dst, NULL, 0, l, 0));
-#endif
 }
 
 /* EOF */
