@@ -1,10 +1,10 @@
 /*
- *  $Id: libnet_build_ipsec.c,v 1.8 2003/11/01 00:11:20 mike Exp $
+ *  $Id: libnet_build_ipsec.c,v 1.11 2004/01/21 19:01:29 mike Exp $
  *
  *  libnet
  *  libnet_build_ipsec.c - IP packet assembler
  *
- *  Copyright (c) 1998 - 2003 Mike D. Schiffman <mike@infonexus.com>
+ *  Copyright (c) 1998 - 2004 Mike D. Schiffman <mike@infonexus.com>
  *  Copyright (c) 2002 Jose Nazario <jose@crimelabs.net>
  *  All rights reserved.
  *
@@ -43,8 +43,7 @@
 
 libnet_ptag_t
 libnet_build_ipsec_esp_hdr(u_int32_t spi, u_int32_t seq, u_int32_t iv,
-             u_int8_t *payload, u_int32_t payload_s, libnet_t *l,
-             libnet_ptag_t ptag)
+u_int8_t *payload, u_int32_t payload_s, libnet_t *l, libnet_ptag_t ptag)
 {
     u_int32_t n, h;
     libnet_pblock_t *p;
@@ -58,8 +57,8 @@ libnet_build_ipsec_esp_hdr(u_int32_t spi, u_int32_t seq, u_int32_t iv,
     n = LIBNET_IPSEC_ESP_HDR_H + payload_s;/* size of memory block */
     h = 0;
 
-	memset(&esp_hdr, 0, sizeof(esp_hdr));
-	esp_hdr.esp_spi = htonl(spi);      /* SPI */
+    memset(&esp_hdr, 0, sizeof(esp_hdr));
+    esp_hdr.esp_spi = htonl(spi);      /* SPI */
     esp_hdr.esp_seq = htonl(seq);      /* ESP sequence number */
     esp_hdr.esp_iv = htonl(iv);        /* initialization vector */
 
@@ -104,7 +103,7 @@ bad:
 
 
 libnet_ptag_t
-libnet_build_ipsec_esp_ftr(u_int8_t len, u_int8_t nxt_hdr, int8_t *auth,
+libnet_build_ipsec_esp_ftr(u_int8_t len, u_int8_t nh, int8_t *auth,
             u_int8_t *payload, u_int32_t payload_s, libnet_t *l,
             libnet_ptag_t ptag)
 {
@@ -121,9 +120,9 @@ libnet_build_ipsec_esp_ftr(u_int8_t len, u_int8_t nxt_hdr, int8_t *auth,
     n = LIBNET_IPSEC_ESP_FTR_H + payload_s;/* size of memory block */
     h = 0;
 
-	memset(&esp_ftr, 0, sizeof(esp_ftr));
-	esp_ftr.esp_pad_len = len;      /* pad length */
-    esp_ftr.esp_nxt_hdr = nxt_hdr;  /* next header pointer */
+    memset(&esp_ftr, 0, sizeof(esp_ftr));
+    esp_ftr.esp_pad_len = len;      /* pad length */
+    esp_ftr.esp_nh = nh;  /* next header pointer */
     esp_ftr.esp_auth = auth;        /* authentication data */
 
     /*
@@ -167,9 +166,9 @@ bad:
 
 
 libnet_ptag_t
-libnet_build_ipsec_ah(u_int8_t nxt_hdr, u_int8_t len, u_int16_t res,
-             u_int32_t spi, u_int32_t seq, u_int32_t auth, u_int8_t *payload,
-             u_int32_t payload_s,  libnet_t *l, libnet_ptag_t ptag)
+libnet_build_ipsec_ah(u_int8_t nh, u_int8_t len, u_int16_t res,
+u_int32_t spi, u_int32_t seq, u_int32_t auth, u_int8_t *payload,
+u_int32_t payload_s,  libnet_t *l, libnet_ptag_t ptag)
 {
     u_int32_t n, h;
     libnet_pblock_t *p;
@@ -193,10 +192,10 @@ libnet_build_ipsec_ah(u_int8_t nxt_hdr, u_int8_t len, u_int16_t res,
         return (-1);
     }
 
-	memset(&ah_hdr, 0, sizeof(ah_hdr));
-	ah_hdr.ah_nxt_hdr = nxt_hdr;       /* next header */
+    memset(&ah_hdr, 0, sizeof(ah_hdr));
+    ah_hdr.ah_nh = nh;       /* next header */
     ah_hdr.ah_len = len;               /* length */
-    ah_hdr.ah_res = 0;                 /* reserved */
+    ah_hdr.ah_res = (res ? htons(res) : 0);
     ah_hdr.ah_spi = htonl(spi);        /* SPI */
     ah_hdr.ah_seq = htonl(seq);        /* AH sequence number */
     ah_hdr.ah_auth = htonl(auth);      /* authentication data */
@@ -223,7 +222,8 @@ libnet_build_ipsec_ah(u_int8_t nxt_hdr, u_int8_t len, u_int16_t res,
         }
     }
 
-    return (ptag ? ptag : libnet_pblock_update(l, p, h, LIBNET_PBLOCK_IPSEC_AH_H));
+    return (ptag ? ptag : libnet_pblock_update(l, p, h, 
+            LIBNET_PBLOCK_IPSEC_AH_H));
 bad:
     libnet_pblock_delete(l, p);
     return (-1);
