@@ -1,10 +1,10 @@
 /*
- *  $Id: libnet_build_mpls.c,v 1.7 2003/10/30 23:26:33 mike Exp $
+ *  $Id: libnet_build_mpls.c,v 1.9 2004/03/01 20:26:12 mike Exp $
  *
  *  libnet
  *  libnet_build_mpls.c - MPLS packet assembler
  *
- *  Copyright (c) 1998 - 2003 Mike D. Schiffman <mike@infonexus.com>
+ *  Copyright (c) 1998 - 2004 Mike D. Schiffman <mike@infonexus.com>
  *  All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -40,8 +40,9 @@
 #endif
 
 libnet_ptag_t
-libnet_build_mpls(u_int32_t label, u_int8_t experimental, u_int8_t bos, u_int8_t ttl,
-            u_int8_t *payload, u_int32_t payload_s, libnet_t *l, libnet_ptag_t ptag)
+libnet_build_mpls(u_int32_t label, u_int8_t experimental, u_int8_t bos, 
+u_int8_t ttl, u_int8_t *payload, u_int32_t payload_s, libnet_t *l,
+libnet_ptag_t ptag)
 {
     u_int32_t n, h;
     libnet_pblock_t *p;
@@ -65,8 +66,8 @@ libnet_build_mpls(u_int32_t label, u_int8_t experimental, u_int8_t bos, u_int8_t
         return (-1);
     }
 
-	memset(&mpls_hdr, 0, sizeof(mpls_hdr));
-	mpls_hdr.mpls_les = htonl((((label & 0x000fffff) << 12) |
+    memset(&mpls_hdr, 0, sizeof(mpls_hdr));
+    mpls_hdr.mpls_les = htonl((((label & 0x000fffff) << 12) |
                               ((experimental & 0x07) <<  9) |
                               ((bos & 0x01)          <<  8) |
                               ((ttl & 0xff))));
