@@ -1,10 +1,10 @@
 /*
- *  $Id: libnet_build_ntp.c,v 1.7 2003/10/30 23:26:33 mike Exp $
+ *  $Id: libnet_build_ntp.c,v 1.9 2004/03/01 20:26:12 mike Exp $
  *
  *  libnet
  *  libnet_build_ntp.c - NTP packet assembler
  *
- *  Copyright (c) 1998 - 2003 Mike D. Schiffman <mike@infonexus.com>
+ *  Copyright (c) 1998 - 2004 Mike D. Schiffman <mike@infonexus.com>
  *  All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -41,12 +41,12 @@
 
 libnet_ptag_t
 libnet_build_ntp(u_int8_t leap_indicator, u_int8_t version, u_int8_t mode,
-            u_int8_t stratum, u_int8_t poll, u_int8_t precision, u_int16_t delay_int,
-            u_int16_t delay_frac, u_int16_t dispersion_int, u_int16_t dispersion_frac,
-            u_int32_t reference_id, u_int32_t ref_ts_int, u_int32_t ref_ts_frac,
-            u_int32_t orig_ts_int, u_int32_t orig_ts_frac, u_int32_t rec_ts_int,
-            u_int32_t rec_ts_frac, u_int32_t xmt_ts_int, u_int32_t xmt_ts_frac,
-            u_int8_t *payload, u_int32_t payload_s, libnet_t *l, libnet_ptag_t ptag)
+u_int8_t stratum, u_int8_t poll, u_int8_t precision, u_int16_t delay_int,
+u_int16_t delay_frac, u_int16_t dispersion_int, u_int16_t dispersion_frac,
+u_int32_t reference_id, u_int32_t ref_ts_int, u_int32_t ref_ts_frac,
+u_int32_t orig_ts_int, u_int32_t orig_ts_frac, u_int32_t rec_ts_int,
+u_int32_t rec_ts_frac, u_int32_t xmt_ts_int, u_int32_t xmt_ts_frac,
+u_int8_t *payload, u_int32_t payload_s, libnet_t *l, libnet_ptag_t ptag)
 {
     u_int32_t n, h;
     libnet_pblock_t *p;
@@ -70,9 +70,9 @@ libnet_build_ntp(u_int8_t leap_indicator, u_int8_t version, u_int8_t mode,
         return (-1);
     }
 
-	memset(&ntp_hdr, 0, sizeof(ntp_hdr));
-	ntp_hdr.ntp_li_vn_mode          = 
-            LIBNET_NTP_DO_LI_VN_MODE(leap_indicator, version, mode);
+    memset(&ntp_hdr, 0, sizeof(ntp_hdr));
+    ntp_hdr.ntp_li_vn_mode          = LIBNET_NTP_DO_LI_VN_MODE(
+                                      leap_indicator, version, mode);
     ntp_hdr.ntp_stratum             = stratum;
     ntp_hdr.ntp_poll                = poll;
     ntp_hdr.ntp_precision           = precision;
@@ -98,7 +98,8 @@ libnet_build_ntp(u_int8_t leap_indicator, u_int8_t version, u_int8_t mode,
 
     if ((payload && !payload_s) || (!payload && payload_s))
     {
-        snprintf(l->err_buf, LIBNET_ERRBUF_SIZE, "%s(): payload inconsistency\n", __func__);
+        snprintf(l->err_buf, LIBNET_ERRBUF_SIZE,
+                "%s(): payload inconsistency\n", __func__);
         goto bad;
     }
 
