@@ -1,10 +1,10 @@
 /*
- *  $Id: libnet_build_ospf.c,v 1.7 2003/10/30 23:26:33 mike Exp $
+ *  $Id: libnet_build_ospf.c,v 1.10 2004/03/01 20:26:12 mike Exp $
  *
  *  libnet
  *  libnet_build_ospf.c - OSPF packet assembler
  *
- *  Copyright (c) 1998 - 2003 Mike D. Schiffman <mike@infonexus.com>
+ *  Copyright (c) 1998 - 2004 Mike D. Schiffman <mike@infonexus.com>
  *  All rights reserved.
  *
  *  Copyright (c) 1999, 2000 Andrew Reiter <areiter@bindview.com>
@@ -43,9 +43,9 @@
 #endif
 
 libnet_ptag_t
-libnet_build_ospfv2(u_int16_t len, u_int8_t type, u_int32_t rtr_id, u_int32_t area_id,
-            u_int16_t sum, u_int16_t autype, u_int8_t *payload, u_int32_t payload_s, 
-            libnet_t *l, libnet_ptag_t ptag)
+libnet_build_ospfv2(u_int16_t len, u_int8_t type, u_int32_t rtr_id, 
+u_int32_t area_id, u_int16_t sum, u_int16_t autype, u_int8_t *payload, 
+u_int32_t payload_s, libnet_t *l, libnet_ptag_t ptag)
 {
     u_int32_t n, h;
     libnet_pblock_t *p;
@@ -69,13 +69,13 @@ libnet_build_ospfv2(u_int16_t len, u_int8_t type, u_int32_t rtr_id, u_int32_t ar
         return (-1);
     }
     
-	memset(&ospf_hdr, 0, sizeof(ospf_hdr));
-	ospf_hdr.ospf_v               = 2;              /* OSPF version 2 */
+    memset(&ospf_hdr, 0, sizeof(ospf_hdr));
+    ospf_hdr.ospf_v               = 2;              /* OSPF version 2 */
     ospf_hdr.ospf_type            = type;           /* Type of pkt */
     ospf_hdr.ospf_len             = htons(h);       /* Pkt len */
     ospf_hdr.ospf_rtr_id.s_addr   = htonl(rtr_id);  /* Router ID */
     ospf_hdr.ospf_area_id.s_addr  = htonl(area_id); /* Area ID */
-    ospf_hdr.ospf_cksum           = sum;
+    ospf_hdr.ospf_sum             = (sum ? htons(sum) : 0);
     ospf_hdr.ospf_auth_type       = htons(autype);  /* Type of auth */
 
     n = libnet_pblock_append(l, p, (u_int8_t *)&ospf_hdr, LIBNET_OSPF_H);
@@ -118,9 +118,9 @@ bad:
 
 libnet_ptag_t
 libnet_build_ospfv2_hello(u_int32_t netmask, u_int16_t interval, u_int8_t opts, 
-            u_int8_t priority, u_int dead_int, u_int32_t des_rtr, u_int32_t bkup_rtr,
-            u_int32_t neighbor, u_int8_t *payload, u_int32_t payload_s, libnet_t *l,
-            libnet_ptag_t ptag)
+u_int8_t priority, u_int32_t dead_int, u_int32_t des_rtr, u_int32_t bkup_rtr,
+u_int32_t neighbor, u_int8_t *payload, u_int32_t payload_s, libnet_t *l,
+libnet_ptag_t ptag)
 {
     u_int32_t n, h;
     libnet_pblock_t *p;
@@ -144,8 +144,8 @@ libnet_build_ospfv2_hello(u_int32_t netmask, u_int16_t interval, u_int8_t opts,
         return (-1);
     }
     
-	memset(&hello_hdr, 0, sizeof(hello_hdr));
-	hello_hdr.hello_nmask.s_addr    = htonl(netmask);  /* Netmask */
+    memset(&hello_hdr, 0, sizeof(hello_hdr));
+    hello_hdr.hello_nmask.s_addr    = htonl(netmask);  /* Netmask */
     hello_hdr.hello_intrvl          = htons(interval);	/* # seconds since last packet sent */
     hello_hdr.hello_opts            = opts;     /* OSPF_* options */
     hello_hdr.hello_rtr_pri         = priority; /* If 0, can't be backup */
@@ -186,8 +186,8 @@ bad:
 
 libnet_ptag_t
 libnet_build_ospfv2_dbd(u_int16_t dgram_len, u_int8_t opts, u_int8_t type,
-            u_int seqnum, u_int8_t *payload, u_int32_t payload_s, libnet_t *l,
-            libnet_ptag_t ptag)
+u_int32_t seqnum, u_int8_t *payload, u_int32_t payload_s, libnet_t *l,
+libnet_ptag_t ptag)
 {
     u_int32_t n, h;
     libnet_pblock_t *p;
@@ -211,7 +211,7 @@ libnet_build_ospfv2_dbd(u_int16_t dgram_len, u_int8_t opts, u_int8_t type,
         return (-1);
     }
     
-	memset(&dbd_hdr, 0, sizeof(dbd_hdr));
+    memset(&dbd_hdr, 0, sizeof(dbd_hdr));
     dbd_hdr.dbd_mtu_len	= htons(dgram_len); /* Max length of IP packet IF can use */
     dbd_hdr.dbd_opts    = opts;	            /* OSPF_* options */
     dbd_hdr.dbd_type    = type;	            /* Type of exchange occuring */
@@ -248,9 +248,8 @@ bad:
 
 
 libnet_ptag_t
-libnet_build_ospfv2_lsr(u_int type, u_int lsid, u_int32_t advrtr, u_int8_t 
-*payload,
-            u_int32_t payload_s, libnet_t *l, libnet_ptag_t ptag)
+libnet_build_ospfv2_lsr(u_int32_t type, u_int lsid, u_int32_t advrtr, 
+u_int8_t *payload, u_int32_t payload_s, libnet_t *l, libnet_ptag_t ptag)
 {
     u_int32_t n, h;
     libnet_pblock_t *p;
@@ -274,8 +273,8 @@ libnet_build_ospfv2_lsr(u_int type, u_int lsid, u_int32_t advrtr, u_int8_t
         return (-1);
     }
 
-	memset(&lsr_hdr, 0, sizeof(lsr_hdr));
-	lsr_hdr.lsr_type         = htonl(type);     /* Type of LS being requested */
+    memset(&lsr_hdr, 0, sizeof(lsr_hdr));
+    lsr_hdr.lsr_type         = htonl(type);     /* Type of LS being requested */
     lsr_hdr.lsr_lsid	     = htonl(lsid);     /* Link State ID */
     lsr_hdr.lsr_adrtr.s_addr = htonl(advrtr);   /* Advertising router */
 
@@ -310,8 +309,8 @@ bad:
 
 
 libnet_ptag_t
-libnet_build_ospfv2_lsu(u_int num, u_int8_t *payload, u_int32_t payload_s,
-            libnet_t *l, libnet_ptag_t ptag)
+libnet_build_ospfv2_lsu(u_int32_t num, u_int8_t *payload, u_int32_t payload_s,
+libnet_t *l, libnet_ptag_t ptag)
 {
     u_int32_t n, h;
     libnet_pblock_t *p;
@@ -335,8 +334,8 @@ libnet_build_ospfv2_lsu(u_int num, u_int8_t *payload, u_int32_t payload_s,
         return (-1);
     }
 
-	memset(&lh_hdr, 0, sizeof(lh_hdr));
-	lh_hdr.lsu_num = htonl(num);   /* Number of LSAs that will be bcasted */
+    memset(&lh_hdr, 0, sizeof(lh_hdr));
+    lh_hdr.lsu_num = htonl(num);   /* Number of LSAs that will be bcasted */
 
     n = libnet_pblock_append(l, p, (u_int8_t *)&lh_hdr, LIBNET_OSPF_LSU_H);
     if (n == -1)
@@ -347,7 +346,7 @@ libnet_build_ospfv2_lsu(u_int num, u_int8_t *payload, u_int32_t payload_s,
     if ((payload && !payload_s) || (!payload && payload_s))
     {
          snprintf(l->err_buf, LIBNET_ERRBUF_SIZE,
-			     "%s(): payload inconsistency\n", __func__);
+                 "%s(): payload inconsistency\n", __func__);
         goto bad;
     }
  
@@ -369,9 +368,9 @@ bad:
 
 
 libnet_ptag_t
-libnet_build_ospfv2_lsa(u_int16_t age, u_int8_t opts, u_int8_t type, u_int lsid, 
-            u_int32_t advrtr, u_int seqnum, u_int16_t sum, u_int16_t len, 
-            u_int8_t *payload, u_int32_t payload_s, libnet_t *l, libnet_ptag_t ptag)
+libnet_build_ospfv2_lsa(u_int16_t age, u_int8_t opts, u_int8_t type, u_int lsid,
+u_int32_t advrtr, u_int32_t seqnum, u_int16_t sum, u_int16_t len,
+u_int8_t *payload, u_int32_t payload_s, libnet_t *l, libnet_ptag_t ptag)
 {
     u_int32_t n, h;
     libnet_pblock_t *p;
@@ -395,14 +394,14 @@ libnet_build_ospfv2_lsa(u_int16_t age, u_int8_t opts, u_int8_t type, u_int lsid,
         return (-1);
     }
 
-	memset(&lsa_hdr, 0, sizeof(lsa_hdr));
-	lsa_hdr.lsa_age         = htons(age);
+    memset(&lsa_hdr, 0, sizeof(lsa_hdr));
+    lsa_hdr.lsa_age         = htons(age);
     lsa_hdr.lsa_opts        = opts;
     lsa_hdr.lsa_type        = type;
     lsa_hdr.lsa_id          = htonl(lsid);
     lsa_hdr.lsa_adv.s_addr  = htonl(advrtr);
     lsa_hdr.lsa_seq         = htonl(seqnum);
-    lsa_hdr.lsa_cksum       = sum;
+    lsa_hdr.lsa_sum         = (sum ? htons(sum) : 0);
     lsa_hdr.lsa_len         = htons(h);
 
     n = libnet_pblock_append(l, p, (u_int8_t *)&lsa_hdr, LIBNET_OSPF_LSA_H);
@@ -445,9 +444,9 @@ bad:
 
 
 libnet_ptag_t
-libnet_build_ospfv2_lsa_rtr(u_int16_t flags, u_int16_t num, u_int id, u_int data, 
-            u_int8_t type, u_int8_t tos, u_int16_t metric, u_int8_t *payload,
-            u_int32_t payload_s, libnet_t *l, libnet_ptag_t ptag)
+libnet_build_ospfv2_lsa_rtr(u_int16_t flags, u_int16_t num, u_int32_t id,
+u_int32_t data, u_int8_t type, u_int8_t tos, u_int16_t metric,
+u_int8_t *payload, u_int32_t payload_s, libnet_t *l, libnet_ptag_t ptag)
 {
     u_int32_t n, h;
     libnet_pblock_t *p;
@@ -471,8 +470,8 @@ libnet_build_ospfv2_lsa_rtr(u_int16_t flags, u_int16_t num, u_int id, u_int data
         return (-1);
     }
 
-	memset(&rtr_lsa_hdr, 0, sizeof(rtr_lsa_hdr));
-	rtr_lsa_hdr.rtr_flags       = htons(flags);
+    memset(&rtr_lsa_hdr, 0, sizeof(rtr_lsa_hdr));
+    rtr_lsa_hdr.rtr_flags       = htons(flags);
     rtr_lsa_hdr.rtr_num         = htons(num);
     rtr_lsa_hdr.rtr_link_id     = htonl(id);
     rtr_lsa_hdr.rtr_link_data   = htonl(data);
@@ -480,7 +479,8 @@ libnet_build_ospfv2_lsa_rtr(u_int16_t flags, u_int16_t num, u_int id, u_int data
     rtr_lsa_hdr.rtr_tos_num     = tos;
     rtr_lsa_hdr.rtr_metric      = htons(metric);
 
-    n = libnet_pblock_append(l, p, (u_int8_t *)&rtr_lsa_hdr, LIBNET_OSPF_LS_RTR_H);
+    n = libnet_pblock_append(l, p, (u_int8_t *)&rtr_lsa_hdr,
+            LIBNET_OSPF_LS_RTR_H);
     if (n == -1)
     {
         goto bad;
@@ -488,8 +488,8 @@ libnet_build_ospfv2_lsa_rtr(u_int16_t flags, u_int16_t num, u_int id, u_int data
 
     if ((payload && !payload_s) || (!payload && payload_s))
     {
-         snprintf(l->err_buf, LIBNET_ERRBUF_SIZE,
-			     "%s(): payload inconsistency\n", __func__);
+        snprintf(l->err_buf, LIBNET_ERRBUF_SIZE,
+                "%s(): payload inconsistency\n", __func__);
         goto bad;
     }
  
@@ -511,8 +511,8 @@ bad:
 
 
 libnet_ptag_t
-libnet_build_ospfv2_lsa_net(u_int32_t nmask, u_int rtrid, u_int8_t *payload, 
-            u_int32_t payload_s, libnet_t *l, libnet_ptag_t ptag)
+libnet_build_ospfv2_lsa_net(u_int32_t nmask, u_int32_t rtrid,
+u_int8_t *payload, u_int32_t payload_s, libnet_t *l, libnet_ptag_t ptag)
 {
     u_int32_t n, h;
     libnet_pblock_t *p;
@@ -536,11 +536,12 @@ libnet_build_ospfv2_lsa_net(u_int32_t nmask, u_int rtrid, u_int8_t *payload,
         return (-1);
     }
 
-	memset(&net_lsa_hdr, 0, sizeof(net_lsa_hdr));
-	net_lsa_hdr.net_nmask.s_addr    = htonl(nmask);
+    memset(&net_lsa_hdr, 0, sizeof(net_lsa_hdr));
+    net_lsa_hdr.net_nmask.s_addr    = htonl(nmask);
     net_lsa_hdr.net_rtr_id          = htonl(rtrid);
 
-    n = libnet_pblock_append(l, p, (u_int8_t *)&net_lsa_hdr, LIBNET_OSPF_LS_NET_H);
+    n = libnet_pblock_append(l, p, (u_int8_t *)&net_lsa_hdr,
+            LIBNET_OSPF_LS_NET_H);
     if (n == -1)
     {
         goto bad;
@@ -571,8 +572,8 @@ bad:
 
 
 libnet_ptag_t
-libnet_build_ospfv2_lsa_sum(u_int32_t nmask, u_int metric, u_int tos, 
-            u_int8_t *payload, u_int32_t payload_s, libnet_t *l, libnet_ptag_t ptag)
+libnet_build_ospfv2_lsa_sum(u_int32_t nmask, u_int32_t metric, u_int tos, 
+u_int8_t *payload, u_int32_t payload_s, libnet_t *l, libnet_ptag_t ptag)
 {
     u_int32_t n, h;
     libnet_pblock_t *p;
@@ -596,12 +597,13 @@ libnet_build_ospfv2_lsa_sum(u_int32_t nmask, u_int metric, u_int tos,
         return (-1);
     }
 
-	memset(&sum_lsa_hdr, 0, sizeof(sum_lsa_hdr));
-	sum_lsa_hdr.sum_nmask.s_addr    = htonl(nmask);
+    memset(&sum_lsa_hdr, 0, sizeof(sum_lsa_hdr));
+    sum_lsa_hdr.sum_nmask.s_addr    = htonl(nmask);
     sum_lsa_hdr.sum_metric          = htonl(metric);
     sum_lsa_hdr.sum_tos_metric      = htonl(tos);
 
-    n = libnet_pblock_append(l, p, (u_int8_t *)&sum_lsa_hdr, LIBNET_OSPF_LS_SUM_H);
+    n = libnet_pblock_append(l, p, (u_int8_t *)&sum_lsa_hdr,
+            LIBNET_OSPF_LS_SUM_H);
     if (n == -1)
     {
         goto bad;
@@ -610,7 +612,7 @@ libnet_build_ospfv2_lsa_sum(u_int32_t nmask, u_int metric, u_int tos,
     if ((payload && !payload_s) || (!payload && payload_s))
     {
         snprintf(l->err_buf, LIBNET_ERRBUF_SIZE,
-			    "%s(): payload inconsistency\n", __func__);
+                "%s(): payload inconsistency\n", __func__);
         goto bad;
     }
  
@@ -633,8 +635,8 @@ bad:
 
 libnet_ptag_t
 libnet_build_ospfv2_lsa_as(u_int32_t nmask, u_int metric, u_int32_t fwdaddr,
-            u_int tag, u_int8_t *payload, u_int32_t payload_s, libnet_t *l, 
-            libnet_ptag_t ptag)
+u_int32_t tag, u_int8_t *payload, u_int32_t payload_s, libnet_t *l,
+libnet_ptag_t ptag)
 {
     u_int32_t n, h;
     libnet_pblock_t *p;
@@ -658,13 +660,14 @@ libnet_build_ospfv2_lsa_as(u_int32_t nmask, u_int metric, u_int32_t fwdaddr,
         return (-1);
     }
 
-	memset(&as_lsa_hdr, 0, sizeof(as_lsa_hdr));
-	as_lsa_hdr.as_nmask.s_addr      = htonl(nmask);
+    memset(&as_lsa_hdr, 0, sizeof(as_lsa_hdr));
+    as_lsa_hdr.as_nmask.s_addr      = htonl(nmask);
     as_lsa_hdr.as_metric            = htonl(metric);
     as_lsa_hdr.as_fwd_addr.s_addr   = htonl(fwdaddr);
     as_lsa_hdr.as_rte_tag           = htonl(tag);
 
-    n = libnet_pblock_append(l, p, (u_int8_t *)&as_lsa_hdr, LIBNET_OSPF_LS_AS_EXT_H);
+    n = libnet_pblock_append(l, p, (u_int8_t *)&as_lsa_hdr,
+            LIBNET_OSPF_LS_AS_EXT_H);
     if (n == -1)
     {
         goto bad;
@@ -673,7 +676,7 @@ libnet_build_ospfv2_lsa_as(u_int32_t nmask, u_int metric, u_int32_t fwdaddr,
     if ((payload && !payload_s) || (!payload && payload_s))
     {
         snprintf(l->err_buf, LIBNET_ERRBUF_SIZE,
-			    "%s(): payload inconsistency\n", __func__);
+                "%s(): payload inconsistency\n", __func__);
         goto bad;
     }
  
