@@ -1,10 +1,10 @@
 /*
- *  $Id: libnet_build_tcp.c,v 1.8 2003/11/01 00:11:20 mike Exp $
+ *  $Id: libnet_build_tcp.c,v 1.11 2004/01/28 19:45:00 mike Exp $
  *
  *  libnet
  *  libnet_build_tcp.c - TCP packet assembler
  *
- *  Copyright (c) 1998 - 2003 Mike D. Schiffman <mike@infonexus.com>
+ *  Copyright (c) 1998 - 2004 Mike D. Schiffman <mike@infonexus.com>
  *  All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -41,9 +41,8 @@
 
 libnet_ptag_t
 libnet_build_tcp(u_int16_t sp, u_int16_t dp, u_int32_t seq, u_int32_t ack,
-            u_int8_t control, u_int16_t win, u_int16_t sum, u_int16_t urg,
-            u_int16_t len, u_int8_t *payload, u_int32_t payload_s, libnet_t *l,
-            libnet_ptag_t ptag)
+u_int8_t control, u_int16_t win, u_int16_t sum, u_int16_t urg, u_int16_t len,
+u_int8_t *payload, u_int32_t payload_s, libnet_t *l, libnet_ptag_t ptag)
 {
     int n, offset;
     u_int32_t i, j;
@@ -69,8 +68,8 @@ libnet_build_tcp(u_int16_t sp, u_int16_t dp, u_int32_t seq, u_int32_t ack,
         return (-1);
     }
 
-	memset(&tcp_hdr, 0, sizeof(tcp_hdr));
-	tcp_hdr.th_sport   = htons(sp);    /* source port */
+    memset(&tcp_hdr, 0, sizeof(tcp_hdr));
+    tcp_hdr.th_sport   = htons(sp);    /* source port */
     tcp_hdr.th_dport   = htons(dp);    /* destination port */
     tcp_hdr.th_seq     = htonl(seq);   /* sequence number */
     tcp_hdr.th_ack     = htonl(ack);   /* acknowledgement number */
@@ -101,8 +100,8 @@ libnet_build_tcp(u_int16_t sp, u_int16_t dp, u_int32_t seq, u_int32_t ack,
     }
 
     tcp_hdr.th_win     = htons(win);   /* window size */
-    tcp_hdr.th_sum     = sum;          /* checksum */ 
-    tcp_hdr.th_urp     = urg;          /* urgent pointer */
+    tcp_hdr.th_sum     = (sum ? htons(sum) : 0);   /* checksum */ 
+    tcp_hdr.th_urp     = htons(urg);          /* urgent pointer */
 
     n = libnet_pblock_append(l, p, (u_int8_t *)&tcp_hdr, LIBNET_TCP_H);
     if (n == -1)
@@ -245,7 +244,7 @@ bad:
 
 libnet_ptag_t
 libnet_build_tcp_options(u_int8_t *options, u_int32_t options_s, libnet_t *l, 
-        libnet_ptag_t ptag)
+libnet_ptag_t ptag)
 {
     int offset, underflow;
     u_int32_t i, j, n, adj_size;
@@ -288,8 +287,8 @@ libnet_build_tcp_options(u_int8_t *options, u_int32_t options_s, libnet_t *l,
             }
             else
             {
-               offset = p_temp->b_len - adj_size;
-               underflow = 1;
+                offset = p_temp->b_len - adj_size;
+                underflow = 1;
             }
         }
     }
