@@ -2,7 +2,7 @@
  *  libnet
  *  libnet_build_token_ring.c - Token Ring (802.5)  packet assembler
  *
- *  Copyright (c) 1998 - 2003 Mike D. Schiffman <mike@infonexus.com>
+ *  Copyright (c) 1998 - 2004 Mike D. Schiffman <mike@infonexus.com>
  *                            Jason Damron      <jsdamron@hushmail.com>
  *  All rights reserved.
  *
@@ -40,9 +40,8 @@
 
 libnet_ptag_t
 libnet_build_token_ring(u_int8_t ac, u_int8_t fc, u_int8_t *dst, u_int8_t *src, 
-                        u_int8_t dsap, u_int8_t ssap, u_int8_t cf, u_int8_t *org, 
-                        u_int16_t type, u_int8_t *payload, u_int32_t payload_s, 
-                        libnet_t *l, libnet_ptag_t ptag)
+u_int8_t dsap, u_int8_t ssap, u_int8_t cf, u_int8_t *org, u_int16_t type,
+u_int8_t *payload, u_int32_t payload_s, libnet_t *l, libnet_ptag_t ptag)
 {
     u_int32_t n, h;
     libnet_pblock_t *p;
@@ -77,8 +76,8 @@ libnet_build_token_ring(u_int8_t ac, u_int8_t fc, u_int8_t *dst, u_int8_t *src,
         return (-1);
     }
 
-	memset(&token_ring_hdr, 0, sizeof(token_ring_hdr));
-	token_ring_hdr.token_ring_access_control    = ac;
+    memset(&token_ring_hdr, 0, sizeof(token_ring_hdr));
+    token_ring_hdr.token_ring_access_control    = ac;
     token_ring_hdr.token_ring_frame_control     = fc;
     memcpy(token_ring_hdr.token_ring_dhost, dst, TOKEN_RING_ADDR_LEN);
     memcpy(token_ring_hdr.token_ring_shost, src, TOKEN_RING_ADDR_LEN);
@@ -120,9 +119,9 @@ bad:
 
 
 libnet_ptag_t
-libnet_autobuild_token_ring(u_int8_t ac, u_int8_t fc, u_int8_t *dst, u_int8_t dsap, 
-                            u_int8_t ssap, u_int8_t cf, u_int8_t *org, u_int16_t type, 
-                            libnet_t *l)
+libnet_autobuild_token_ring(u_int8_t ac, u_int8_t fc, u_int8_t *dst, 
+u_int8_t dsap, u_int8_t ssap, u_int8_t cf, u_int8_t *org, u_int16_t type, 
+libnet_t *l)
 {
     u_int32_t n, h;
     struct libnet_token_ring_addr *src;
@@ -167,8 +166,8 @@ libnet_autobuild_token_ring(u_int8_t ac, u_int8_t fc, u_int8_t *dst, u_int8_t ds
         return (-1);
     }
 
-	memset(&token_ring_hdr, 0, sizeof(token_ring_hdr));
-	token_ring_hdr.token_ring_access_control    = ac;
+    memset(&token_ring_hdr, 0, sizeof(token_ring_hdr));
+    token_ring_hdr.token_ring_access_control    = ac;
     token_ring_hdr.token_ring_frame_control     = fc;
     memcpy(token_ring_hdr.token_ring_dhost, dst, TOKEN_RING_ADDR_LEN);
     memcpy(token_ring_hdr.token_ring_shost, src, TOKEN_RING_ADDR_LEN);
