@@ -1,10 +1,10 @@
 /*
- *  $Id: libnet_init.c,v 1.9 2003/10/30 23:26:33 mike Exp $
+ *  $Id: libnet_init.c,v 1.17 2004/03/16 18:40:59 mike Exp $
  *
  *  libnet
  *  libnet_init.c - Initilization routines.
  *
- *  Copyright (c) 1998 - 2003 Mike D. Schiffman <mike@infonexus.com>
+ *  Copyright (c) 1998 - 2004 Mike D. Schiffman <mike@infonexus.com>
  *  All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -39,7 +39,6 @@
 #include "../include/win32/libnet.h"
 #endif
 
-
 libnet_t *
 libnet_init(int injection_type, char *device, char *err_buf)
 {
@@ -48,7 +47,8 @@ libnet_init(int injection_type, char *device, char *err_buf)
 #if !defined(__WIN32__)
     if (getuid() && geteuid())
     {
-        snprintf(err_buf, LIBNET_ERRBUF_SIZE, "UID != 0\n");
+        snprintf(err_buf, LIBNET_ERRBUF_SIZE,
+                "%s(): UID or EUID of 0 required\n", __func__);
         goto bad;
     }
 #else
@@ -56,7 +56,8 @@ libnet_init(int injection_type, char *device, char *err_buf)
 
     if ((WSAStartup(0x0202, &wsaData)) != 0)
     {
-        snprintf(err_buf, LIBNET_ERRBUF_SIZE, "Unable to initialize Winsock 2\n");
+        snprintf(err_buf, LIBNET_ERRBUF_SIZE, 
+                "%s(): unable to initialize winsock 2\n", __func__);
         goto bad;
     }
 #endif
@@ -64,7 +65,7 @@ libnet_init(int injection_type, char *device, char *err_buf)
     l = (libnet_t *)malloc(sizeof (libnet_t));
     if (l == NULL)
     {
-        snprintf(err_buf, LIBNET_ERRBUF_SIZE, "malloc(): %s\n",
+        snprintf(err_buf, LIBNET_ERRBUF_SIZE, "%s(): malloc(): %s\n", __func__,
                 strerror(errno));
         goto bad;
     }
@@ -72,27 +73,21 @@ libnet_init(int injection_type, char *device, char *err_buf)
     memset(l, 0, sizeof (*l));
 
     l->injection_type   = injection_type;
-    l->protocol         = IPPROTO_RAW;
     l->ptag_state       = LIBNET_PTAG_INITIALIZER;
     l->device           = (device ? strdup(device) : NULL);
-    l->protocol_blocks  = NULL;
-    l->pblock_end       = NULL;
-    l->total_size       = 0;
-   
-    strncpy(l->label, LIBNET_LABEL_DEFAULT, LIBNET_LABEL_SIZE);
-	l->label[sizeof(l->label)] = '\0';
 
-    if (libnet_select_device(l) == -1)
-    {
-        snprintf(err_buf, LIBNET_ERRBUF_SIZE, "libnet_select_device(): %s\n",
-                l->err_buf);
-        goto bad;
-    }
+    strncpy(l->label, LIBNET_LABEL_DEFAULT, LIBNET_LABEL_SIZE);
+    l->label[sizeof(l->label)] = '\0';
 
     switch (l->injection_type)
     {
         case LIBNET_LINK:
         case LIBNET_LINK_ADV:
+            if (libnet_select_device(l) == -1)
+            {
+                snprintf(err_buf, LIBNET_ERRBUF_SIZE, l->err_buf);
+		goto bad;
+            }
             if (libnet_open_link(l) == -1)
             {
                 snprintf(err_buf, LIBNET_ERRBUF_SIZE, l->err_buf);
@@ -117,7 +112,7 @@ libnet_init(int injection_type, char *device, char *err_buf)
             break;
         default:
             snprintf(err_buf, LIBNET_ERRBUF_SIZE,
-                    "unsupported injection type\n");
+                    "%s(): unsupported injection type\n", __func__);
             goto bad;
             break;
     }
@@ -132,7 +127,6 @@ bad:
     return (NULL);
 }
 
-
 void
 libnet_destroy(libnet_t *l)
 {
@@ -148,7 +142,6 @@ libnet_destroy(libnet_t *l)
     }
 }
 
-
 void
 libnet_clear_packet(libnet_t *l)
 {
@@ -175,7 +168,6 @@ libnet_clear_packet(libnet_t *l)
     }
 }
 
-
 void
 libnet_stats(libnet_t *l, struct libnet_stats *ls)
 {
@@ -184,12 +176,11 @@ libnet_stats(libnet_t *l, struct libnet_stats *ls)
         return;
     }
 
-    ls->packets_sent    = l->stats.packets_sent;
-    ls->packet_errors   = l->stats.packet_errors;
-    ls->bytes_written   = l->stats.bytes_written;
+    ls->packets_sent  = l->stats.packets_sent;
+    ls->packet_errors = l->stats.packet_errors;
+    ls->bytes_written = l->stats.bytes_written;
 }
 
-
 int
 libnet_getfd(libnet_t *l)
 {
@@ -201,7 +192,6 @@ libnet_getfd(libnet_t *l)
     return (l->fd);
 }
 
-
 int8_t *
 libnet_getdevice(libnet_t *l)
 {
@@ -213,7 +203,6 @@ libnet_getdevice(libnet_t *l)
     return (l->device);
 }
 
-
 u_int8_t *
 libnet_getpbuf(libnet_t *l, libnet_ptag_t ptag)
 {
@@ -236,7 +225,6 @@ libnet_getpbuf(libnet_t *l, libnet_ptag_t ptag)
     }
 }
 
-
 u_int32_t
 libnet_getpbuf_size(libnet_t *l, libnet_ptag_t ptag)
 {
@@ -259,5 +247,27 @@ libnet_getpbuf_size(libnet_t *l, libnet_ptag_t ptag)
     }
 }
 
+u_int32_t
+libnet_getpacket_size(libnet_t *l)
+{
+    libnet_pblock_t *p;
+    u_int32_t n;
+
+    if (l == NULL)
+    { 
+        return (0);
+    } 
+
+    n = 0;
+    p = l->protocol_blocks;
+    if (p)
+    {
+        for (; p; p = p->next)
+        {
+            n += p->b_len;
+        }
+    }
+    return (n);
+}
 
 /* EOF */
