@@ -1,10 +1,10 @@
 /*
- *  $Id: libnet_internal.c,v 1.8 2003/10/30 23:26:33 mike Exp $
+ *  $Id: libnet_internal.c,v 1.14 2004/03/16 18:40:59 mike Exp $
  *
  *  libnet
  *  libnet_internal.c - secret routines!
  *
- *  Copyright (c) 1998 - 2003 Mike D. Schiffman <mike@infonexus.com>
+ *  Copyright (c) 1998 - 2004 Mike D. Schiffman <mike@infonexus.com>
  *  All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -39,9 +39,8 @@
 #include "../include/win32/libnet.h"
 #endif
 
-
 void
-__libnet_dump_hex(u_int8_t *packet, u_int32_t len, int swap, FILE *stream)
+libnet_diag_dump_hex(u_int8_t *packet, u_int32_t len, int swap, FILE *stream)
 {
     int i, s_cnt;
     u_int16_t *p;
@@ -75,10 +74,8 @@ __libnet_dump_hex(u_int8_t *packet, u_int32_t len, int swap, FILE *stream)
 
 
 void
-__libnet_dump_context(libnet_t *l)
+libnet_diag_dump_context(libnet_t *l)
 {
-    struct protoent *p_ent;
- 
     if (l == NULL)
     { 
         return;
@@ -86,10 +83,6 @@ __libnet_dump_context(libnet_t *l)
 
     fprintf(stderr, "fd:\t\t%d\n", l->fd);
  
-    p_ent = getprotobynumber(l->protocol);
-    fprintf(stderr, "protocol:\t%s (%d)\n", p_ent ? p_ent->p_name : 
-            "UNABLE TO DETERMINE", l->protocol);
- 
     switch (l->injection_type)
     {
         case LIBNET_LINK:
@@ -132,7 +125,7 @@ __libnet_dump_context(libnet_t *l)
 }
 
 void
-__libnet_dump_pblock(libnet_t *l)
+libnet_diag_dump_pblock(libnet_t *l)
 {
     u_int32_t n;
     libnet_pblock_t *p;
@@ -140,17 +133,24 @@ __libnet_dump_pblock(libnet_t *l)
     for (p = l->protocol_blocks; p; p = p->next)
     {
         fprintf(stderr, "pblock type:\t%s\n", 
-                __libnet_dump_pblock_type(p->type));
+                libnet_diag_dump_pblock_type(p->type));
         fprintf(stderr, "ptag number:\t%d\n", p->ptag);
+        fprintf(stderr, "IP offset:\t%d\n", p->ip_offset);
         fprintf(stderr, "pblock address:\t%p\n", p);
         fprintf(stderr, "next pblock\t%p ", p->next);
-		if (p->next)
-			fprintf(stderr, "(%s)", __libnet_dump_pblock_type(p->next->type));
-		fprintf(stderr, "\n");
+        if (p->next)
+        {
+            fprintf(stderr, "(%s)",
+                    libnet_diag_dump_pblock_type(p->next->type));
+        }
+        fprintf(stderr, "\n");
         fprintf(stderr, "prev pblock\t%p ", p->prev);
-		if (p->prev)
-			fprintf(stderr, "(%s)", __libnet_dump_pblock_type(p->prev->type));
-		fprintf(stderr, "\n");
+        if (p->prev)
+        {
+            fprintf(stderr, "(%s)",
+                    libnet_diag_dump_pblock_type(p->prev->type));
+        }
+        fprintf(stderr, "\n");
         fprintf(stderr, "buf:\t\t");
         for (n = 0; n < p->b_len; n++)
         {
@@ -170,8 +170,8 @@ __libnet_dump_pblock(libnet_t *l)
     }
 }
 
-int8_t *
-__libnet_dump_pblock_type(u_int8_t type)
+char *
+libnet_diag_dump_pblock_type(u_int8_t type)
 {
     static int8_t buf[50];
     switch (type)
@@ -280,9 +280,29 @@ __libnet_dump_pblock_type(u_int8_t type)
             return ("fddi header");
         case LIBNET_PBLOCK_TOKEN_RING_H:
             return ("token ring header");
+        case LIBNET_PBLOCK_BGP4_HEADER_H:
+            return ("bgp header");
+        case LIBNET_PBLOCK_BGP4_OPEN_H:
+            return ("bgp open header");
+        case LIBNET_PBLOCK_BGP4_UPDATE_H:
+            return ("bgp update header");
+        case LIBNET_PBLOCK_BGP4_NOTIFICATION_H:
+            return ("bgp notification header");
+        case LIBNET_PBLOCK_GRE_H:
+            return ("gre header");
+        case LIBNET_PBLOCK_GRE_SRE_H:
+            return ("gre sre header");
+        case LIBNET_PBLOCK_IPV6_FRAG_H:
+            return ("ipv6 fragmentation header");
+        case LIBNET_PBLOCK_IPV6_ROUTING_H:
+            return ("ipv6 routing header");
+        case LIBNET_PBLOCK_IPV6_DESTOPTS_H:
+            return ("ipv6 destination options header");
+        case LIBNET_PBLOCK_IPV6_HBHOPTS_H:
+            return ("ipv6 hop by hop options header");
         default:
             snprintf(buf, sizeof(buf),
-				    "unknown or unlisted pblock type %d", type);
+                    "%s(): unknown pblock type: %d", __func__, type);
             return (buf);
     }
     return ("unreachable code");
