@@ -1,10 +1,10 @@
 /*
- *  $Id: libnet_raw.c,v 1.5 2003/10/30 23:26:33 mike Exp $
+ *  $Id: libnet_raw.c,v 1.9 2004/02/18 18:19:00 mike Exp $
  *
  *  libnet
  *  libnet_raw.c - raw sockets routines
  *
- *  Copyright (c) 1998 - 2003 Mike D. Schiffman <mike@infonexus.com>
+ *  Copyright (c) 1998 - 2004 Mike D. Schiffman <mike@infonexus.com>
  *  All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -40,44 +40,44 @@
 #endif
 
 #if defined (__WIN32__)
-
 int
 libnet_open_raw4(libnet_t *l)
 {
-    return libnet_open_link(l);
+    return (libnet_open_link(l));
 }
 
 int
 libnet_open_raw6(libnet_t *l)
 {
-    return libnet_open_link(l);
+    return (libnet_open_link(l));
 }
 
 int
 libnet_close_raw4(libnet_t *l)
 {
-    return libnet_close_link_interface(l);
+    return (libnet_close_link_interface(l));
 }
 
 int
 libnet_close_raw6(libnet_t *l)
 {
-    return libnet_close_link_interface(l);
+    return (libnet_close_link_interface(l));
 }
-
 #else
 int
 libnet_open_raw4(libnet_t *l)
 {
+    int len;
+
 #if !(__WIN32__)
-     int one = 1;
+     int n = 1;
 #if (__svr4__)
-     void *oneptr = &one;
+     void *nptr = &n;
 #else
-    int *oneptr = &one;
+    int *nptr = &n;
 #endif  /* __svr4__ */
 #else 
-	BOOL one;
+	BOOL n;
 #endif
 
     if (l == NULL)
@@ -85,37 +85,91 @@ libnet_open_raw4(libnet_t *l)
         return (-1);
     } 
 
-    l->fd = socket(AF_INET, SOCK_RAW, l->protocol);
+    l->fd = socket(AF_INET, SOCK_RAW, IPPROTO_RAW);
     if (l->fd == -1)
     {
         snprintf(l->err_buf, LIBNET_ERRBUF_SIZE, 
-                "libnet_open_raw4: SOCK_RAW allocation failed: %s\n",
-                strerror(errno));
+                "%s(): SOCK_RAW allocation failed: %s\n",
+		 __func__, strerror(errno));
         goto bad;
     }
+
+#ifdef IP_HDRINCL
+/* 
+ * man raw
+ *
+ * The IPv4 layer generates an IP header when sending a packet unless
+ * the IP_HDRINCL socket option is enabled on the socket.  When it
+ * is enabled, the packet must contain an IP header.  For
+ * receiving the IP header is always included in the packet.
+ */
 #if !(__WIN32__)
-    if (setsockopt(l->fd, IPPROTO_IP, IP_HDRINCL, oneptr, sizeof(one)) == -1)
+    if (setsockopt(l->fd, IPPROTO_IP, IP_HDRINCL, nptr, sizeof(n)) == -1)
 #else
-    one = TRUE;
-    if (setsockopt(l->fd, IPPROTO_IP, IP_HDRINCL, (int8_t *)&one,
-            sizeof(one)) == -1)
+    n = TRUE;
+    if (setsockopt(l->fd, IPPROTO_IP, IP_HDRINCL, (int8_t *)&n,
+            sizeof(n)) == -1)
 #endif
 
     {
         snprintf(l->err_buf, LIBNET_ERRBUF_SIZE, 
-                "libnet_open_raw4: set IP_HDRINCL failed: %s\n",
-                strerror(errno));
+                "%s(): set IP_HDRINCL failed: %s\n",
+                __func__, strerror(errno));
         goto bad;
     }
-#if (__linux__)
-    if (setsockopt(l->fd, SOL_SOCKET, SO_BROADCAST, oneptr, sizeof(one)) == -1)
+#endif /*  IP_HDRINCL  */
+
+#ifdef SO_SNDBUF
+
+/*
+ * man 7 socket 
+ *
+ * Sets and  gets  the  maximum  socket  send buffer in bytes. 
+ *
+ * Taken from libdnet by Dug Song
+ */
+    len = sizeof(n);
+    if (getsockopt(l->fd, SOL_SOCKET, SO_SNDBUF, &n, &len) < 0)
+    {
+        snprintf(l->err_buf, LIBNET_ERRBUF_SIZE, 
+		 "%s(): get SO_SNDBUF failed: %s\n",
+		 __func__, strerror(errno));
+        goto bad;
+    }
+    
+    for (n += 128; n < 1048576; n += 128)
+    {
+        if (setsockopt(l->fd, SOL_SOCKET, SO_SNDBUF, &n, len) < 0) 
+        {
+            if (errno == ENOBUFS)
+            {
+                break;
+            }
+             snprintf(l->err_buf, LIBNET_ERRBUF_SIZE, 
+                     "%s(): set SO_SNDBUF failed: %s\n",
+                     __func__, strerror(errno));
+             goto bad;
+        }
+    }
+#endif
+
+#ifdef SO_BROADCAST
+/*
+ * man 7 socket
+ *
+ * Set or get the broadcast flag. When  enabled,  datagram  sockets
+ * receive packets sent to a broadcast address and they are allowed
+ * to send packets to a broadcast  address.   This  option  has  no
+ * effect on stream-oriented sockets.
+ */
+    if (setsockopt(l->fd, SOL_SOCKET, SO_BROADCAST, nptr, sizeof(n)) == -1)
     {
         snprintf(l->err_buf, LIBNET_ERRBUF_SIZE,
-                "libnet_open_raw4: set SO_BROADCAST failed: %s\n",
-                strerror(errno));
+                "%s(): set SO_BROADCAST failed: %s\n",
+                __func__, strerror(errno));
         goto bad;
     }
-#endif  /* __linux__ */
+#endif  /*  SO_BROADCAST  */
     return (l->fd);
 
 bad:
@@ -165,11 +219,11 @@ libnet_open_raw6(libnet_t *l)
         return (-1);
     } 
 
-    l->fd = socket(PF_INET6, SOCK_RAW, l->protocol);
+    l->fd = socket(PF_INET6, SOCK_RAW, IPPROTO_RAW);
     if (l->fd == -1)
     {
         snprintf(l->err_buf, LIBNET_ERRBUF_SIZE, 
-                "libnet_open_raw6(): SOCK_RAW allocation failed: %s\n",
+                "%s(): SOCK_RAW allocation failed: %s\n", __func__,
                 strerror(errno));
         goto bad;
     }
@@ -178,7 +232,7 @@ libnet_open_raw6(libnet_t *l)
     if (setsockopt(l->fd, SOL_SOCKET, SO_BROADCAST, oneptr, sizeof(one)) == -1)
     {
         snprintf(l->err_buf, LIBNET_ERRBUF_SIZE,
-                "libnet_open_raw6(): set SO_BROADCAST failed: %s\n",
+                "%s(): set SO_BROADCAST failed: %s\n", __func__,
                 strerror(errno));
         goto bad;
     }
@@ -199,7 +253,5 @@ libnet_close_raw6(libnet_t *l)
     }
     return (close(l->fd));
 }
-
-
 #endif
 /* EOF */
